InfiniteQueryData<TPage> class

Holds the accumulated pages for an infinite query.

Each element in pages represents one page of data. pageParams contains the corresponding page parameters used to fetch each page.

Constructors

InfiniteQueryData({required List<TPage> pages, required List pageParams})
Creates an infinite query data container.
const
InfiniteQueryData.empty()
Creates an empty infinite query data container.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
Whether any pages have been loaded.
no setter
isNotEmpty bool
Whether at least one page has been loaded.
no setter
length int
The number of loaded pages.
no setter
pageParams List
The page parameters used to fetch each page, in the same order as pages.
final
pages List<TPage>
All loaded pages in order.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendPage(TPage page, dynamic pageParam) InfiniteQueryData<TPage>
Returns a new InfiniteQueryData with an appended page.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prependPage(TPage page, dynamic pageParam) InfiniteQueryData<TPage>
Returns a new InfiniteQueryData with a prepended page.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override