QueryObserver<T> class
A utility interface for building observer patterns with custom state maps.
Primarily used as the base subscription wrapper for useQuery.
Constructors
-
QueryObserver({required QueryClient client, required List queryKey, required QueryOptions<
T> options})
Properties
- client → QueryClient
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
options
→ QueryOptions<
T> -
final
- queryKey → List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subscribe(
void listener(QueryResult< T> )) → QueryResult<T> -
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited