MutationBuilder<TData, TVariables> class
A widget that manages mutation state and rebuilds when it changes.
MutationBuilder<User, UpdateNameParams>(
mutator: (params) => api.updateUser(params),
builder: (context, result) {
return ElevatedButton(
onPressed: result.isLoading
? null
: () => result.mutate(UpdateNameParams(name: 'New Name')),
child: result.isLoading
? CircularProgressIndicator()
: Text('Save'),
);
},
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MutationBuilder
Constructors
-
MutationBuilder({Key? key, required MutatorFn<
TData, TVariables> mutator, required Widget builder(BuildContext context, MutationResult<TData, TVariables> result), OnMutateFn<TVariables> ? onMutate, OnMutationSuccessFn<TData, TVariables> ? onSuccess, OnMutationErrorFn<TVariables> ? onError, OnMutationSettledFn<TData, TVariables> ? onSettled, int retry = 0, RetryDelayFn? retryDelay, RetryWhenFn? retryWhen}) -
Creates a MutationBuilder.
const
Properties
-
builder
→ Widget Function(BuildContext context, MutationResult<
TData, TVariables> result) -
Builder function called with the mutation result.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
mutator
→ MutatorFn<
TData, TVariables> -
The function that performs the mutation.
final
-
onError
→ OnMutationErrorFn<
TVariables> ? -
Called on mutation failure.
final
-
onMutate
→ OnMutateFn<
TVariables> ? -
Called before the mutation runs.
final
-
onSettled
→ OnMutationSettledFn<
TData, TVariables> ? -
Called after mutation completes (success or failure).
final
-
onSuccess
→ OnMutationSuccessFn<
TData, TVariables> ? -
Called on successful mutation.
final
- retry → int
-
Number of retries. Default: 0 (mutations don't retry by default).
final
- retryDelay → RetryDelayFn?
-
Delay between retries.
final
- retryWhen → RetryWhenFn?
-
Predicate for conditional retry.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MutationBuilder< TData, TVariables> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited